@@ -26,7 +26,7 @@ import logging.handlers
 import os
 from typing import Union
 
-from telegram_crypto_price_bot.bot.bot_config import BotConfigTypes
+from telegram_crypto_price_bot.bot.bot_config_types import BotConfigTypes
 from telegram_crypto_price_bot.config.config_object import ConfigObject
 
 
